"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const UpdateChanges_1 = require("../common/UpdateChanges");
const util_1 = require("../common/util");
const version = '12.0.0';
exports.default = () => (host, context) => {
    context.logger.info(`Applying migration for Ignite UI for Angular to version ${version}`);
    const COMPONENTS = [
        {
            component: 'igx-bottom-nav',
            tags: ['igx-bottom-nav-item', 'igx-tab-panel', 'igx-tab'],
            tabItem: 'igx-bottom-nav-item',
            headerItem: 'igx-bottom-nav-header',
            panelItem: 'igx-bottom-nav-content',
            iconDirective: 'igxBottomNavHeaderIcon',
            labelDirective: 'igxBottomNavHeaderLabel'
        },
        {
            component: 'igx-tabs',
            tags: ['igx-tabs-group', 'igx-tab-item'],
            tabItem: 'igx-tab-item',
            headerItem: 'igx-tab-header',
            panelItem: 'igx-tab-content',
            iconDirective: 'igxTabHeaderIcon',
            labelDirective: 'igxTabHeaderLabel'
        }
    ];
    const update = new UpdateChanges_1.UpdateChanges(__dirname, host, context);
    const changes = new Map();
    const htmlFiles = update.templateFiles;
    const applyChanges = () => {
        for (const [path, change] of changes.entries()) {
            let buffer = host.read(path).toString();
            change.sort((c, c1) => c.position - c1.position)
                .reverse()
                .forEach(c => buffer = c.apply(buffer));
            host.overwrite(path, buffer);
        }
    };
    const addChange = (path, change) => {
        if (changes.has(path)) {
            changes.get(path).push(change);
        }
        else {
            changes.set(path, [change]);
        }
    };
    const isEmptyOrSpaces = (str) => str === null || str === '' || str === '\n' || str.match(/^ *$/) !== null;
    // Replace the tabsType input with tabsAligment
    for (const path of htmlFiles) {
        util_1.findElementNodes(util_1.parseFile(host, path), 'igx-tabs')
            .forEach(node => {
            if (util_1.hasAttribute(node, 'type')) {
                const { startTag, file } = util_1.getSourceOffset(node);
                const tabsType = util_1.getAttribute(node, 'type')[0];
                let alignment;
                if (tabsType.value.toLowerCase() === 'fixed') {
                    alignment = 'justify';
                }
                else if (tabsType.value.toLowerCase() === 'contentfit') {
                    alignment = 'start';
                }
                const tabAlignment = alignment ? ` tabAlignment="${alignment}"` : '';
                addChange(file.url, new util_1.FileChange(startTag.end - 1, tabAlignment));
            }
        });
    }
    applyChanges();
    changes.clear();
    for (const comp of COMPONENTS) {
        for (const path of htmlFiles) {
            // Replace the <ng-template igxTab> if any with <igx-tab-item>
            util_1.findElementNodes(util_1.parseFile(host, path), comp.tags)
                .map(tab => util_1.findElementNodes([tab], 'ng-template'))
                .reduce((prev, curr) => prev.concat(curr), [])
                .filter(template => util_1.hasAttribute(template, 'igxTab'))
                .forEach(node => {
                const { startTag, endTag, file } = util_1.getSourceOffset(node);
                const content = file.content.substring(startTag.end, endTag.start);
                const textToReplace = file.content.substring(startTag.start, endTag.end);
                const tabPanel = `<${comp.headerItem}>${content}</${comp.headerItem}>`;
                addChange(file.url, new util_1.FileChange(startTag.start, tabPanel, textToReplace, 'replace'));
            });
            applyChanges();
            changes.clear();
            // Convert label and icon to igx-tab-header children ->
            // <igx-icon igxTabHeaderIcon> and <span igxTabHeaderLabel>
            util_1.findElementNodes(util_1.parseFile(host, path), comp.tags).
                map(node => util_1.getSourceOffset(node)).
                forEach(offset => {
                const { startTag, endTag, file, node } = offset;
                // Label content
                let labelText = '';
                if (util_1.hasAttribute(node, 'label')) {
                    const labelAttr = util_1.getAttribute(node, 'label')[0];
                    labelText = `\n<span ${comp.labelDirective}>${labelAttr.value}</span>\n`;
                }
                // Icon content
                let iconText = '';
                if (util_1.hasAttribute(node, 'icon')) {
                    const iconAttr = util_1.getAttribute(node, 'icon')[0];
                    iconText = `\n<igx-icon ${comp.iconDirective}>${iconAttr.value}</igx-icon>`;
                }
                // RouterLink
                let routerLinkText = '';
                if (util_1.hasAttribute(node, 'routerLink')) {
                    const routerLink = util_1.getAttribute(node, 'routerLink')[0];
                    routerLinkText = ` ${routerLink.name}="${routerLink.value}"`;
                }
                if (iconText || labelText || routerLinkText) {
                    // eslint-disable-next-line max-len
                    const tabHeader = `\n<${comp.headerItem}${routerLinkText}>${iconText}${labelText}</${comp.headerItem}>`;
                    addChange(file.url, new util_1.FileChange(startTag.end, tabHeader));
                }
            });
            applyChanges();
            changes.clear();
            // Grab the content between <igx-tabs-group> and create a <igx-tab-content>
            util_1.findElementNodes(util_1.parseFile(host, path), comp.tags)
                .map(node => util_1.getSourceOffset(node))
                .forEach(offset => {
                const tabHeader = offset.node.children.find(c => c.name === comp.headerItem);
                if (tabHeader) {
                    const content = offset.file.content.substring(tabHeader.sourceSpan.end.offset, offset.endTag.start);
                    if (!isEmptyOrSpaces(content)) {
                        const tabPanel = `\n<${comp.panelItem}>${content}</${comp.panelItem}>\n`;
                        addChange(offset.file.url, new util_1.FileChange(tabHeader.sourceSpan.end.offset, tabPanel, content, 'replace'));
                    }
                }
            });
            applyChanges();
            changes.clear();
            // Insert a comment indicating the change/replacement
            util_1.findElementNodes(util_1.parseFile(host, path), comp.component).
                map(node => util_1.getSourceOffset(node)).
                forEach(offset => {
                const { startTag, file } = offset;
                // eslint-disable-next-line max-len
                const commentText = `<!--NOTE: This component has been updated by Infragistics migration: v${version}\nPlease check your template whether all bindings/event handlers are correct.-->\n`;
                addChange(file.url, new util_1.FileChange(startTag.start, commentText));
            });
            applyChanges();
            changes.clear();
        }
    }
    // Apply all selector and input changes
    update.applyChanges();
};
